'''
## This file is autogenerated from macrosynergy setup.py.

It contains version information for the macrosynergy package.

short_version: 1.2.3

version: 1.2.3

full_version: 1.2.3

git_revision: a5ba82d41640d52835c35ee0a8a6f0bb13f640ca

release: True

'''
short_version: str = '1.2.3'
version: str = '1.2.3'
full_version: str = '1.2.3'
git_revision: str = 'a5ba82d41640d52835c35ee0a8a6f0bb13f640ca'
release: bool = True
if not release:
    version = full_version
